=== modified file 'Makefile'
--- Makefile	2005-12-02 05:25:53 +0000
+++ Makefile	2005-12-12 23:14:43 +0000
@@ -2,6 +2,8 @@
 
 check:
 	./bzr selftest $(tests)
+	@echo "Running all tests with no locale."
+	LC_CTYPE= LANG=C LC_ALL= ./bzr selftest $(tests)
 
 check-msgeditor:
 	./bzr --no-plugins selftest -v msgeditor

=== modified file 'NEWS'
--- NEWS	2005-12-13 05:40:51 +0000
+++ NEWS	2005-12-14 07:53:26 +0000
@@ -168,8 +168,16 @@
     * Much better error message if one of the test suites can't be 
       imported.  (Martin Pool)
 
+    * Make check now runs the test suite twice - once with the default locale,
+      and once with all locales forced to C, to expose bugs. This is not 
+      trivially done within python, so for now its only triggered by running
+      Make check. Integrators and packagers who wish to check for full 
+      platform support should run 'make check' to test the source.
+      (Robert Collins)
+
     * Tests can now run TestSkipped if they can't execute for any reason.
-      (Martin Pool)
+      (Martin Pool) (NB: TestSkipped should only be raised for correctable
+      reasons - see the wiki spec ImprovingBzrTestSuite).
 
   INTERNALS:
 

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2005-12-13 05:48:04 +0000
+++ bzrlib/tests/test_msgeditor.py	2005-12-14 09:01:40 +0000
@@ -23,28 +23,25 @@
 from bzrlib.msgeditor import make_commit_message_template
 from bzrlib.tests import TestCaseInTempDir, TestSkipped
 
-from bzrlib.tests.treeshape import build_tree_contents
-
-
-def make_uncommitted_tree():
-    """Build a branch with uncommitted changes in the cwd."""
-    b = Branch.initialize('.')
-    working_tree = b.working_tree()
-    filename = u'hell\u00d8'
-    try:
-        build_tree_contents([(filename, 'contents of hello')])
-    except UnicodeEncodeError:
-        raise TestSkipped("can't build unicode working tree in "
+
+class MsgEditorTest(TestCaseInTempDir):
+
+    def make_uncommitted_tree(self):
+        """Build a branch with uncommitted unicode named changes in the cwd."""
+        b = Branch.initialize('.')
+        working_tree = b.working_tree()
+        filename = u'hell\u00d8'
+        try:
+            self.build_tree_contents([(filename, 'contents of hello')])
+        except UnicodeEncodeError:
+            raise TestSkipped("can't build unicode working tree in "
                 "filesystem encoding %s" % sys.getfilesystemencoding())
-    working_tree.add(filename)
-    return working_tree
-
-
-class MsgEditorTest(TestCaseInTempDir):
-
+        working_tree.add(filename)
+        return working_tree
+    
     def test_commit_template(self):
         """Test building a commit message template"""
-        working_tree = make_uncommitted_tree()
+        working_tree = self.make_uncommitted_tree()
         template = make_commit_message_template(working_tree, None)
         self.assertEqualDiff(template,
 u"""\

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2005-12-13 05:40:51 +0000
+++ bzrlib/tests/test_selftest.py	2005-12-14 09:01:40 +0000
@@ -20,9 +20,13 @@
 import sys
 import unittest
 
-from bzrlib.tests import TestCase, _load_module_by_name, \
-        TestSkipped
-import bzrlib.tests
+from bzrlib.tests import (
+                          _load_module_by_name,
+                          TestCase,
+                          TestCaseInTempDir,
+                          TestSkipped,
+                          TextTestRunner,
+                          )
 
 
 class SelftestTests(TestCase):
@@ -38,6 +42,7 @@
 
 
 class MetaTestLog(TestCase):
+
     def test_logging(self):
         """Test logs are captured when a test fails."""
         self.log('a test message')
@@ -45,13 +50,25 @@
         self.assertContainsRe(self._get_log(), 'a test message\n')
 
 
+class TestTreeShape(TestCaseInTempDir):
+
+    def test_unicode_paths(self):
+        filename = u'hell\u00d8'
+        try:
+            self.build_tree_contents([(filename, 'contents of hello')])
+        except UnicodeEncodeError:
+            raise TestSkipped("can't build unicode working tree in "
+                "filesystem encoding %s" % sys.getfilesystemencoding())
+        self.failUnlessExists(filename)
+
+
 class TestSkippedTest(TestCase):
     """Try running a test which is skipped, make sure it's reported properly."""
     def test_skipped_test(self):
         # must be hidden in here so it's not run as a real test
         def skipping_test():
             raise TestSkipped('test intentionally skipped')
-        runner = bzrlib.tests.TextTestRunner(stream=self._log_file)
+        runner = TextTestRunner(stream=self._log_file)
         test = unittest.FunctionTestCase(skipping_test)
         result = runner.run(test)
         self.assertTrue(result.wasSuccessful())

